Forms for attaching realms to functions.
Forms for attaching realms to functions.
(defn name next & rest-args)Define a function with realms for return value and arguments.
(defn myfun :- realm/integer "docstring" [a :- realm/string]
...)
Define a function with realms for return value and arguments. ``` (defn myfun :- realm/integer "docstring" [a :- realm/string] ...) ```
(fn-realm var)Return the realm of a function defined via defn given its var.
Return the realm of a function defined via [[defn]] given its var.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |