Mostly clj/s.
Exceptions indicated.

active.data.realm.inspection

Predicates, selectors, and realms for processing realm values as input.

Predicates, selectors, and realms for processing realm values as input.
raw docstring

anyclj/s

Realm containing the any realm.

Realm containing the any realm.
sourceraw docstring

any?clj/s

source

booleanclj/s

Realm containing the boolean realm.

Realm containing the boolean realm.
sourceraw docstring

boolean?clj/s

source

charclj/s

Realm containing the char realm.

Realm containing the char realm.
sourceraw docstring

char?clj/s

source

delayedclj/s

Realm containing delayed realms.

Realm containing delayed realms.
sourceraw docstring

delayed-realm-delayclj/s≠

clj
(delayed-realm-delay delayed-realm)
(delayed-realm-delay delayed-realm value)
cljs
source (clj)source (cljs)

delayed?clj/s

(delayed? thing)
source

descriptionclj/s≠

clj
(description realm)
(description realm value)

Description string for realm.

Description string for realm.
cljs
source (clj)source (cljs)raw docstring

enumclj/s

Realm containing enum realms.

Realm containing enum realms.
sourceraw docstring

enum-realm-valuesclj/s≠

clj
(enum-realm-values enum-realm)
(enum-realm-values enum-realm value)
cljs
source (clj)source (cljs)

enum?clj/s

(enum? thing)
source

from-predicateclj/s

Realm containing predicate realms.

Realm containing predicate realms.
sourceraw docstring

from-predicate-realmclj/s

source (clj)source (cljs)

from-predicate?clj/s

(from-predicate? thing)
source

functionclj/s

Realm containing function realms.

Realm containing function realms.
sourceraw docstring

function-case-optional-arguments-realmclj/s≠

clj
(function-case-optional-arguments-realm function-case)
(function-case-optional-arguments-realm function-case value)
cljs
source (clj)source (cljs)

function-case-positional-argument-realmsclj/s≠

clj
(function-case-positional-argument-realms function-case)
(function-case-positional-argument-realms function-case value)
cljs
source (clj)source (cljs)

function-case-return-realmclj/s≠

clj
(function-case-return-realm function-case)
(function-case-return-realm function-case value)
cljs
source (clj)source (cljs)

function-realm-casesclj/s≠

clj
(function-realm-cases function-realm)
(function-realm-cases function-realm value)
cljs
source (clj)source (cljs)

function?clj/s

(function? thing)
source

integer-from-toclj/s

Realm containing integer-from-to realms.

Realm containing integer-from-to realms.
sourceraw docstring

integer-from-to-realm-fromclj/s≠

clj
(integer-from-to-realm-from integer-from-to-realm)
(integer-from-to-realm-from integer-from-to-realm value)
cljs
source (clj)source (cljs)

integer-from-to-realm-toclj/s≠

clj
(integer-from-to-realm-to integer-from-to-realm)
(integer-from-to-realm-to integer-from-to-realm value)
cljs
source (clj)source (cljs)

integer-from-to?clj/s

(integer-from-to? thing)
source

intersectionclj/s

Realm containing intersection realms.

Realm containing intersection realms.
sourceraw docstring

intersection-realm-realmsclj/s≠

clj
(intersection-realm-realms intersection-realm)
(intersection-realm-realms intersection-realm value)
cljs
source (clj)source (cljs)

intersection?clj/s

(intersection? thing)
source

keywordclj/s

Realm containing the keyword realm.

Realm containing the keyword realm.
sourceraw docstring

keyword?clj/s

source

map-ofclj/s

Realm containing map-of realms.

Realm containing map-of realms.
sourceraw docstring

map-of-realm-key-realmclj/s≠

clj
(map-of-realm-key-realm map-of-realm)
(map-of-realm-key-realm map-of-realm value)
cljs
source (clj)source (cljs)

map-of-realm-value-realmclj/s≠

clj
(map-of-realm-value-realm map-of-realm)
(map-of-realm-value-realm map-of-realm value)
cljs
source (clj)source (cljs)

map-of?clj/s

(map-of? thing)
source

map-with-keysclj/s

Realm containing map-with-keys realms.

Realm containing map-with-keys realms.
sourceraw docstring

map-with-keys-realm-mapclj/s≠

clj
(map-with-keys-realm-map map-with-keys-realm)
(map-with-keys-realm-map map-with-keys-realm value)
cljs
source (clj)source (cljs)

map-with-keys?clj/s

(map-with-keys? thing)
source

map-with-tagclj/s

Realm containing map-with-tag realms.

Realm containing map-with-tag realms.
sourceraw docstring

map-with-tag-realm-keyclj/s≠

clj
(map-with-tag-realm-key map-with-tag-realm)
(map-with-tag-realm-key map-with-tag-realm value)
cljs
source (clj)source (cljs)

map-with-tag-realm-valueclj/s≠

clj
(map-with-tag-realm-value map-with-tag-realm)
(map-with-tag-realm-value map-with-tag-realm value)
cljs
source (clj)source (cljs)

map-with-tag?clj/s

(map-with-tag? thing)
source

metadataclj/s≠

clj
(metadata realm)
(metadata realm value)

Metadata for the realm, for additional semantically relevant information.

Metadata for the realm, for additional semantically relevant information.
cljs
source (clj)source (cljs)raw docstring

namedclj/s

Realm containing named realms.

Realm containing named realms.
sourceraw docstring

named-realm-nameclj/s≠

clj
(named-realm-name named-realm)
(named-realm-name named-realm value)
cljs
source (clj)source (cljs)

named-realm-realmclj/s≠

clj
(named-realm-realm named-realm)
(named-realm-realm named-realm value)
cljs
source (clj)source (cljs)

named?clj/s

(named? thing)
source

numberclj/s

Realm containing the number realm.

Realm containing the number realm.
sourceraw docstring

number?clj/s

source

optionalclj/s

Realm containing optional realms.

Realm containing optional realms.
sourceraw docstring

optional-realm-realmclj/s≠

clj
(optional-realm-realm optional-realm)
(optional-realm-realm optional-realm value)
cljs
source (clj)source (cljs)

optional?clj/s

(optional? thing)
source

predicateclj/s≠

clj
(predicate realm)
(predicate realm value)

Shallow predicate for values of the realm.

Shallow predicate for values of the realm.
cljs
source (clj)source (cljs)raw docstring

rationalclj

Realm containing the rational realm.

Realm containing the rational realm.
sourceraw docstring

rational?clj/s

source

real-rangeclj/s

Realm containing real-range realms.

Realm containing real-range realms.
sourceraw docstring

real-range-realm-clusive-leftclj/s≠

clj
(real-range-realm-clusive-left real-range-realm)
(real-range-realm-clusive-left real-range-realm value)
cljs
source (clj)source (cljs)

real-range-realm-clusive-rightclj/s≠

clj
(real-range-realm-clusive-right real-range-realm)
(real-range-realm-clusive-right real-range-realm value)
cljs
source (clj)source (cljs)

real-range-realm-leftclj/s≠

clj
(real-range-realm-left real-range-realm)
(real-range-realm-left real-range-realm value)
cljs
source (clj)source (cljs)

real-range-realm-rightclj/s≠

clj
(real-range-realm-right real-range-realm)
(real-range-realm-right real-range-realm value)
cljs
source (clj)source (cljs)

real-range?clj/s

(real-range? thing)
source

realmclj/s

Realm containing all realms

Realm containing all realms
sourceraw docstring

realm?clj/s

(realm? thing)
source

recordclj/s

Realm containing record realms.

Realm containing record realms.
sourceraw docstring

record-realm-constructorclj/s≠

clj
(record-realm-constructor record-realm)
(record-realm-constructor record-realm value)
cljs
source (clj)source (cljs)

record-realm-field-getterclj/s≠

clj
(record-realm-field-getter record-realm-field)
(record-realm-field-getter record-realm-field value)
cljs
source (clj)source (cljs)

record-realm-field-nameclj/s≠

clj
(record-realm-field-name record-realm-field)
(record-realm-field-name record-realm-field value)
cljs
source (clj)source (cljs)

record-realm-field-realmclj/s≠

clj
(record-realm-field-realm record-realm-field)
(record-realm-field-realm record-realm-field value)
cljs
source (clj)source (cljs)

record-realm-fieldsclj/s≠

clj
(record-realm-fields record-realm)
(record-realm-fields record-realm value)
cljs
source (clj)source (cljs)

record-realm-nameclj/s≠

clj
(record-realm-name record-realm)
(record-realm-name record-realm value)
cljs
source (clj)source (cljs)

record?clj/s

(record? thing)
source

sequence-ofclj/s

Realm containing sequence-of realms.

Realm containing sequence-of realms.
sourceraw docstring

sequence-of-realm-realmclj/s≠

clj
(sequence-of-realm-realm sequence-of-realm)
(sequence-of-realm-realm sequence-of-realm value)
cljs
source (clj)source (cljs)

sequence-of?clj/s

(sequence-of? thing)
source

set-ofclj/s

Realm containing set-of realms.

Realm containing set-of realms.
sourceraw docstring

set-of-realm-realmclj/s≠

clj
(set-of-realm-realm set-of-realm)
(set-of-realm-realm set-of-realm value)
cljs
source (clj)source (cljs)

set-of?clj/s

(set-of? thing)
source

stringclj/s

Realm containing the string realm.

Realm containing the string realm.
sourceraw docstring

string?clj/s

source

symbolclj/s

Realm containing the symbol realm.

Realm containing the symbol realm.
sourceraw docstring

symbol?clj/s

source

tupleclj/s

Realm containing tuple realms.

Realm containing tuple realms.
sourceraw docstring

tuple-realm-realmsclj/s≠

clj
(tuple-realm-realms tuple-realm)
(tuple-realm-realms tuple-realm value)
cljs
source (clj)source (cljs)

tuple?clj/s

(tuple? thing)
source

unionclj/s

Realm containing union realms.

Realm containing union realms.
sourceraw docstring

union-realm-realmsclj/s≠

clj
(union-realm-realms union-realm)
(union-realm-realms union-realm value)
cljs
source (clj)source (cljs)

union?clj/s

(union? thing)
source

uuidclj/s

Realm containing the uuid realm.

Realm containing the uuid realm.
sourceraw docstring

uuid?clj/s

source

cljdoc builds & hosts documentation for Clojure/Script libraries